@@ -653,7 +653,7 @@ xfce_keyboard_settings_edit_shortcut (XfceKeyboardSettings *settings,
       /* Request a new shortcut from the user */
       dialog = xfce_shortcut_dialog_new ("commands", command, command);
       g_signal_connect (dialog, "validate-shortcut", G_CALLBACK (xfce_keyboard_settings_validate_shortcut), settings);
-      response = xfce_shortcut_dialog_run (XFCE_SHORTCUT_DIALOG (dialog));
+      response = xfce_shortcut_dialog_run (XFCE_SHORTCUT_DIALOG (dialog), gtk_widget_get_toplevel (GTK_WIDGET (tree_view)));
 
       if (G_LIKELY (response == GTK_RESPONSE_OK))
         {
@@ -764,7 +764,10 @@ xfce_keyboard_settings_validate_shortcut (XfceShortcutDialog   *dialog,
                                                 info->shortcut->command,
                                                 FALSE);
 
-      accepted = response == GTK_RESPONSE_ACCEPT;
+      if (G_UNLIKELY (response == GTK_RESPONSE_ACCEPT))
+        xfce_shortcuts_provider_reset_shortcut (info->provider, shortcut);
+      else
+        accepted = FALSE;
 
       xfce_keyboard_settings_free_shortcut_info (info);
     }
@@ -905,6 +908,7 @@ xfce_keyboard_settings_add_button_clicked (XfceKeyboardSettings *settings,
 {
   GtkWidget   *command_dialog;
   GtkWidget   *shortcut_dialog;
+  GtkWidget   *parent;
   const gchar *shortcut;
   const gchar *command;
   gboolean     finished = FALSE;
@@ -942,7 +946,8 @@ xfce_keyboard_settings_add_button_clicked (XfceKeyboardSettings *settings,
       g_signal_connect (shortcut_dialog, "validate-shortcut", G_CALLBACK (xfce_keyboard_settings_validate_shortcut), settings);
 
       /* Run shortcut dialog until a valid shortcut is entered or the dialog is cancelled */
-      response = xfce_shortcut_dialog_run (XFCE_SHORTCUT_DIALOG (shortcut_dialog));
+      parent = glade_xml_get_widget (settings->priv->glade_xml, "keyboard-shortcuts-dialog");
+      response = xfce_shortcut_dialog_run (XFCE_SHORTCUT_DIALOG (shortcut_dialog), parent);
 
       /* Only continue if the shortcut dialog succeeded */
       if (G_LIKELY (response == GTK_RESPONSE_OK))
@@ -1030,7 +1035,7 @@ xfce_keyboard_settings_reset_button_clicked (XfceKeyboardSettings *settings)
 
   response = xfce_message_dialog (NULL, _("Reset to Defaults"), GTK_STOCK_DIALOG_QUESTION,
                                   _("Reset to Defaults"),
-                                  _("This will reset <b>all</b> shortcuts to their default "
+                                  _("This will reset all shortcuts to their default "
                                     "values. Do you really want to do this?"),
                                   GTK_STOCK_NO, GTK_RESPONSE_NO,
                                   GTK_STOCK_YES, GTK_RESPONSE_YES,
